@@ -18,7 +18,7 @@ int av_init_module_uxze(struct vmodule *module)
     struct avfs *avfs;
     const char *uxze_args[3];
     const char *xze_args[2];
-    struct ext_info uxze_exts[2];
+    struct ext_info uxze_exts[5];
 
     uxze_args[0] = "xz";
     uxze_args[1] = "-d";
@@ -27,8 +27,11 @@ int av_init_module_uxze(struct vmodule *module)
     xze_args[0] = "xz";
     xze_args[1] = NULL;
 
-    uxze_exts[0].from = ".lzma",   uxze_exts[0].to = NULL;
-    uxze_exts[1].from = NULL;
+    uxze_exts[0].from = ".tar.xz",   uxze_exts[0].to = ".tar";
+    uxze_exts[1].from = ".txz",  uxze_exts[1].to = ".tar";
+    uxze_exts[2].from = ".xz",   uxze_exts[2].to = NULL;
+    uxze_exts[3].from = ".lzma",   uxze_exts[3].to = NULL;
+    uxze_exts[4].from = NULL;
 
     return av_init_filt(module, AV_VER, "uxze", uxze_args, xze_args,
                         uxze_exts, &avfs);
